@@ -406,7 +406,7 @@ sub add_config_hooks_run {
             $self->$_();
         }
         else {
-            print "WARNING: cannot run configure hook: `$_'\n";
+            error "cannot run configure hook: `$_'";
         }
     }
 
@@ -1285,6 +1285,7 @@ sub apxs {
     my($self, $q, $ok_fail) = @_;
     return unless $self->{APXS};
     my $val = qx($self->{APXS} -q $q 2>/dev/null);
+    chomp $val if defined $val; # apxs post-2.0.40 adds a new line
     unless ($val) {
         if ($ok_fail) {
             return "";
@@ -1309,6 +1310,7 @@ sub pop_dir {
 
 sub add_inc {
     my $self = shift;
+    return if $ENV{MOD_PERL}; #already setup by mod_perl
     require lib;
     # make sure that the Apache-Test dev libs will be first in @INC,
     # followed by modperl's lib, followed by blib and finally core
