@@ -1,13 +1,22 @@
 package ModPerl::RegistryLoader;
 
-use Apache::Const -compile => qw(OPT_EXECCGI);
+use strict;
+use warnings;
+
+use ModPerl::RegistryCooker ();
+use APR::Pool ();
+
+use Apache::Const -compile => qw(OK HTTP_OK OPT_EXECCGI);
 use Carp;
 
 our @ISA = ();
 
-sub new {
+# using create() instead of new() since the latter is inherited from
+# the SUPER class, and it's used inside handler() from the SUPER class
+sub create {
     my $class = shift;
     my $self = bless {@_} => ref($class)||$class;
+    $self->{pool} = APR::Pool->new();
     $self->load_package($self->{package});
     return $self;
 }
@@ -31,9 +40,9 @@ sub handler {
     }
     else {
         # try to translate URI->filename
-        if (my $func = $self->{trans}) {
+        if (exists $self->{trans} and ref($self->{trans}) eq 'CODE') {
             no strict 'refs';
-            $filename = $func->($uri);
+            $filename = $self->{trans}->($uri);
             unless (-e $filename) {
                 $self->warn("Cannot find a translated from uri: $filename");
                 return;
@@ -41,8 +50,11 @@ sub handler {
         } else {
             # try to guess
             (my $guess = $uri) =~ s|^/||;
-            $filename = Apache::server_root_relative($guess);
-            $self->warn("Trying to guess filename based on uri");
+
+            $self->warn("Trying to guess filename based on uri")
+                if $self->{debug};
+
+            $filename = Apache::server_root_relative($self->{pool}, $guess);
             unless (-e $filename) {
                 $self->warn("Cannot find guessed file: $filename",
                             "provide \$filename or 'trans' sub");
@@ -55,31 +67,43 @@ sub handler {
         $self->warn("*** uri=$uri, filename=$filename");
     }
 
-    my $r = bless {
-		   uri      => $uri,
-		   filename => $filename,
-		  } => ref($self) || $self;
+    my $rl = bless {
+        uri      => $uri,
+        filename => $filename,
+        package  => $self->{package},
+    } => ref($self) || $self;
 
-    $r->SUPER::handler;
+    __PACKAGE__->SUPER::handler($rl);
 
 }
 
+# XXX: s/my_// for qw(my_finfo my_slurp_filename);
+# when when finfo() and slurp_filename() are ported to 2.0 and
+# RegistryCooker is starting to use them
+
 sub filename { shift->{filename} }
-sub finfo    { shift->{filename} }
+sub status { Apache::HTTP_OK }
+sub my_finfo    { shift->{filename} }
 sub uri      { shift->{uri} }
 sub path_info {}
 sub allow_options { Apache::OPT_EXECCGI } #will be checked again at run-time
 sub log_error { shift; die @_ if $@; warn @_; }
-*log_reason = \&log_error;
-sub run {} # don't run the script
+sub run { return Apache::OK } # don't run the script
 sub server { shift }
 
+# the preloaded file needs to be precompiled into the package
+# specified by the 'package' attribute, not RegistryLoader
+sub namespace_root {
+    join '::', ModPerl::RegistryCooker::NAMESPACE_ROOT,
+        shift->[ModPerl::RegistryCooker::REQ]->{package};
+}
+
 # override Apache class methods called by Modperl::Registry*. normally
 # only available at request-time via blessed request_rec pointer
-sub slurp_filename {
+sub my_slurp_filename {
     my $r = shift;
     my $filename = $r->filename;
-    open my $fh, $filename;
+    open my $fh, $filename or die "can't open $filename: $!";
     local $/;
     my $code = <$fh>;
     return \$code;
@@ -97,7 +121,7 @@ sub load_package {
 
 sub warn {
     my $self = shift;
-    Apache::warn(__PACKAGE__ . ": @_\n");
+    Apache->warn(__PACKAGE__ . ": @_\n");
 }
 
 1;
