@@ -41,6 +41,8 @@ modperl_interp_t *modperl_interp_select(request_rec *r, conn_rec *c,
     interp = modperl_interp_select(r, c, s); \
     aTHX = interp->perl
 
+#define MP_aTHX aTHX
+
 apr_status_t modperl_interp_pool_destroy(void *data);
 
 typedef apr_status_t (*modperl_interp_mip_walker_t)(pTHX_ 
@@ -61,6 +63,8 @@ void modperl_interp_mip_walk_servers(PerlInterpreter *current_perl,
 
 #define MP_dINTERP_SELECT(r, c, s) dNOOP
 
+#define MP_aTHX 0
+
 #endif /* USE_ITHREADS */
 
 #endif /* MODPERL_INTERP_H */
