@@ -3,13 +3,15 @@ package TestAPI::conn_rec;
 use strict;
 use warnings FATAL => 'all';
 
+use Apache::TestUtil;
 use Apache::Test;
 
 use Apache::RequestRec ();
 use Apache::RequestUtil ();
 use Apache::Connection ();
 
-use Apache::Const -compile => 'OK';
+use Apache::Const -compile => qw(OK REMOTE_HOST REMOTE_NAME
+    REMOTE_NOLOOKUP REMOTE_DOUBLE_REV);
 
 #this test module is only for testing fields in the conn_rec
 #listed in apache_structures.map
@@ -19,7 +21,7 @@ sub handler {
 
     my $c = $r->connection;
 
-    plan $r, tests => 15;
+    plan $r, tests => 22;
 
     ok $c;
 
@@ -57,6 +59,20 @@ sub handler {
     #output_filters
     #remain
 
+    # Connection utils (XXX: move to conn_utils.pm?)
+
+    # $c->get_remote_host
+    ok $c->get_remote_host() || 1;
+
+    for (Apache::REMOTE_HOST, Apache::REMOTE_NAME, 
+        Apache::REMOTE_NOLOOKUP, Apache::REMOTE_DOUBLE_REV) {
+        ok $c->get_remote_host($_) || 1;
+    }
+
+    ok $c->get_remote_host(Apache::REMOTE_HOST, 
+        $c->base_server->dir_config) || 1;
+    ok $c->get_remote_host(Apache::REMOTE_HOST, $r->dir_config) || 1;
+
     Apache::OK;
 }
 
